@@ -163,11 +163,11 @@ summary.dsm.var <- function(object, alpha=0.05, boxplot.coef=1.5,
       object$off.set <- as.vector(off)
 
       if(object$var.prop){
-        var.prop <- dsm.var.prop(object$dsm.obj, object$pred.data,
+        var.prop <- dsm_var_prop(object$dsm.obj, object$pred.data,
                                  object$off.set, object$seglen.varname,
                                  object$type.pred)
       }else{
-        var.prop <- dsm.var.gam(object$dsm.obj, object$pred.data,object$off.set,
+        var.prop <- dsm_var_gam(object$dsm.obj, object$pred.data,object$off.set,
                                  object$seglen.varname, object$type.pred)
       }
 
